pub struct FileSystemTrie<T>(/* private fields */);Expand description
A container for a directory tree-like cache where the “files” are a data type of your choice.
Implementations
Sourceimpl<T> FileSystemTrie<T>
impl<T> FileSystemTrie<T>
pub fn new() -> Self
Sourcepub fn create_dir(&mut self, path: impl AsRef<Utf8Path>)
pub fn create_dir(&mut self, path: impl AsRef<Utf8Path>)
Adds a directory to the trie. If parent directories do not exist, they will be created.
Sourcepub fn create_file(&mut self, path: impl AsRef<Utf8Path>, value: T) -> Option<T>
pub fn create_file(&mut self, path: impl AsRef<Utf8Path>, value: T) -> Option<T>
Adds a file to the trie with the given value. If parent directories do not exist, they will be created. If there already was a file at the given path, the original value will be returned.
Sourcepub fn contains_dir(&self, path: impl AsRef<Utf8Path>) -> bool
pub fn contains_dir(&self, path: impl AsRef<Utf8Path>) -> bool
Returns whether or not a directory exists at the given path.
Sourcepub fn contains_file(&self, path: impl AsRef<Utf8Path>) -> bool
pub fn contains_file(&self, path: impl AsRef<Utf8Path>) -> bool
Returns whether or not a file exists at the given path.
Sourcepub fn contains(&self, path: impl AsRef<Utf8Path>) -> bool
pub fn contains(&self, path: impl AsRef<Utf8Path>) -> bool
Returns whether or not a file or directory exists at the given path.
Sourcepub fn get_dir_size(&self, path: impl AsRef<Utf8Path>) -> Option<usize>
pub fn get_dir_size(&self, path: impl AsRef<Utf8Path>) -> Option<usize>
Gets the number of direct children in the directory at the given path, if it exists.
Sourcepub fn get_file(&self, path: impl AsRef<Utf8Path>) -> Option<&T>
pub fn get_file(&self, path: impl AsRef<Utf8Path>) -> Option<&T>
Gets an immutable reference to the value in the file at the given path, if it exists.
Sourcepub fn get_file_mut(&mut self, path: impl AsRef<Utf8Path>) -> Option<&mut T>
pub fn get_file_mut(&mut self, path: impl AsRef<Utf8Path>) -> Option<&mut T>
Gets a mutable reference to the value in the file at the given path, if it exists.
Sourcepub fn get_or_create_file(&mut self, path: impl AsRef<Utf8Path>, value: T) -> &T
pub fn get_or_create_file(&mut self, path: impl AsRef<Utf8Path>, value: T) -> &T
Gets an immutable reference to the value in the file at the given path or creates the file with the given value if it doesn’t.
Sourcepub fn get_or_create_file_with(
&mut self,
path: impl AsRef<Utf8Path>,
f: impl FnOnce() -> T,
) -> &T
pub fn get_or_create_file_with( &mut self, path: impl AsRef<Utf8Path>, f: impl FnOnce() -> T, ) -> &T
Gets an immutable reference to the value in the file at the given path or creates the file with the given value if it doesn’t.
Sourcepub fn get_or_create_file_mut(
&mut self,
path: impl AsRef<Utf8Path>,
value: T,
) -> &mut T
pub fn get_or_create_file_mut( &mut self, path: impl AsRef<Utf8Path>, value: T, ) -> &mut T
Gets a mutable reference to the value in the file at the given path or creates the file with the given value if it doesn’t.
Sourcepub fn get_or_create_file_with_mut(
&mut self,
path: impl AsRef<Utf8Path>,
f: impl FnOnce() -> T,
) -> &mut T
pub fn get_or_create_file_with_mut( &mut self, path: impl AsRef<Utf8Path>, f: impl FnOnce() -> T, ) -> &mut T
Gets a mutable reference to the value in the file at the given path or creates the file with the given value if it doesn’t.
Sourcepub fn get_dir_prefix(&self, path: impl AsRef<Utf8Path>) -> &Utf8Path
pub fn get_dir_prefix(&self, path: impl AsRef<Utf8Path>) -> &Utf8Path
Gets the longest prefix of the given path that is the path of a directory in the trie.
Sourcepub fn remove_file(&mut self, path: impl AsRef<Utf8Path>) -> Option<T>
pub fn remove_file(&mut self, path: impl AsRef<Utf8Path>) -> Option<T>
Removes the file at the given path if it exists, and returns the original value.
Sourcepub fn remove_dir(&mut self, path: impl AsRef<Utf8Path>) -> bool
pub fn remove_dir(&mut self, path: impl AsRef<Utf8Path>) -> bool
Removes the directory at the given path and all of its contents if it exists, and returns whether or not it existed.
Sourcepub fn iter_dir(
&self,
path: impl AsRef<Utf8Path>,
) -> Option<FileSystemTrieDirIter<'_, T>>
pub fn iter_dir( &self, path: impl AsRef<Utf8Path>, ) -> Option<FileSystemTrieDirIter<'_, T>>
Given the path to a directory, returns an iterator over its children if it exists.
The iterator’s items are of the form (key, value) where key is the name of the child as
&str and value is the data of the child if it’s a file, as Option<&T>.
Sourcepub fn iter_prefix(
&self,
path: impl AsRef<Utf8Path>,
) -> Option<FileSystemTrieIter<'_, T>>
pub fn iter_prefix( &self, path: impl AsRef<Utf8Path>, ) -> Option<FileSystemTrieIter<'_, T>>
Given the path to a directory, returns an iterator over immutable references to its descendant files if it exists.